@@ -343,3 +343,17 @@ void MainWindow::on_actionServizioPubblico_Online_triggered()
     process.start("sh /opt/serviziopubblico/script/official.sh");
     process.waitForFinished();
 }
+
+void MainWindow::on_actionRicorda_un_amico_triggered()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/ricorda.sh");
+    process.waitForFinished();
+}
+
+void MainWindow::on_actionDonazione_triggered()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/donate.sh");
+    process.waitForFinished();
+}
