@@ -104,6 +104,10 @@ private slots:
 
     void on_actionServizioPubblico_Online_triggered();
 
+    void on_actionRicorda_un_amico_triggered();
+
+    void on_actionDonazione_triggered();
+
 private:
     Ui::MainWindow *ui;
 };
